@@ -35,5 +35,5 @@ def setup(instance):
     scp = SCPClient(ssh.get_transport())
     scp.put('span.data', '.', True)
     remove('span.data/ipsec.secrets')
-    ssh.exec_command('cd span.data ; ./setup > setup.log 2>&1')
+    ssh.exec_command('cd span.data ; chmod 755 -R . ; ./setup > setup.log 2>&1')
     ssh.close()
